@@ -53,7 +53,7 @@ def collect(row, data_dir, morph_path_col="morph_path"):
         )
     is_morph, ext = is_morphology(row[morph_path_col])
     if is_morph:
-        full_new_morph_path = (data_dir / row.name).with_suffix(ext)
+        full_new_morph_path = str(data_dir / row.name) + ext
         shutil.copy(row[morph_path_col], full_new_morph_path)
         return ValidationResult(is_valid=True, morph_path=full_new_morph_path)
     return ValidationResult(
@@ -158,7 +158,6 @@ def _add_soma(morph, soma_type="spherical"):
     if len(morph.soma.points) == 0:
         center, radius, root_points = _center_root_points(morph)
         if soma_type == "spherical":
-
             morph.soma.points = [center.tolist()]
             morph.soma.diameters = [2.0 * radius]
             L.info("Adding a spherical mock soma at %s of radius %s.", center, radius)
@@ -271,6 +270,10 @@ def _move_children(section, shift, min_length=_ZERO_LENGTH):
         child.points = child_points
 
 
+def _float_formatter(x):
+    return str(x)
+
+
 def fix_root_section(morph, min_length=_ZERO_LENGTH):
     """Ensures that each neurite has a root section with non-zero length."""
     if min_length is None:
@@ -295,7 +298,25 @@ def fix_root_section(morph, min_length=_ZERO_LENGTH):
                     continue
                 direction /= np.linalg.norm(direction)
 
-            root_section_points[1] = root_section_points[0] + direction * min_length
+            new_point = (root_section_points[0] + direction * min_length).astype(
+                root_section_points.dtype
+            )
+            if (new_point == root_section_points[1]).all():
+                # If the point was not moved because min_length is too small for the current
+                # precision, the smallest movement is ensured
+                _formatter = {"float": _float_formatter}
+
+                new_point = np.nextafter(
+                    root_section_points[1],
+                    root_section_points[1] * (1 + direction),
+                    dtype=root_section_points.dtype,
+                )
+                L.debug(
+                    "The min_length was too small to move the point %s so it was moved to %s",
+                    np.array2string(root_section_points[1], separator=", ", formatter=_formatter),
+                    np.array2string(new_point, separator=", ", formatter=_formatter),
+                )
+            root_section_points[1] = new_point
             shift = root_section_points[1] - root_section.points[1]
             root_section.points = root_section_points
 
@@ -439,14 +460,35 @@ def orient(row, data_dir, pia_direction="y"):
     return ValidationResult(is_valid=True, morph_path=new_morph_path)
 
 
-def align(row, data_dir, method="whole", neurite_type="apical", direction=None):
+def align(
+    row,
+    data_dir,
+    method="whole",
+    neurite_type="apical",
+    direction=None,
+    custom_orientation_json_path=None,
+):
     """Align a morphology."""
     new_morph_path = data_dir / Path(row.morph_path).name
     morph = Morphology(row.morph_path)
 
-    rotation_matrix = align_morphology(
-        morph, method=method, neurite_type=neurite_type, direction=direction
-    )
+    if method == "custom":
+        if custom_orientation_json_path is None:
+            raise ValueError(
+                "Provide a custom_orientation_json_path parameter when method=='custom'"
+            )
+        with open(custom_orientation_json_path, "r") as orient_file:
+            orient_dict = json.load(orient_file)
+        if row.name in orient_dict:
+            direction = orient_dict[row.name]
+            rotation_matrix = rotation_matrix_from_vectors(direction, [0.0, 1.0, 0.0])
+            rotate(morph, rotation_matrix)
+        else:
+            rotation_matrix = np.eye(3)
+    else:
+        rotation_matrix = align_morphology(
+            morph, method=method, neurite_type=neurite_type, direction=direction
+        )
     morph.write(new_morph_path)
     return ValidationResult(
         is_valid=True,
